@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.021';
+$Time::C::VERSION = '0.022';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -110,7 +110,7 @@ method mktime ($c: :$epoch =, :$second =, :$minute =, :$hour =, :$mday =, :$mont
             if (defined $wday) { $t->day_of_week = $wday; }
             else { $t->{wday} = 0; }
         } elsif (defined $yday) {
-            $t = Time::C->new($year)->day($yday);
+            $t = Time::C->new($year)->day_of_year($yday);
         } else { # we have neither month, week, or day of year!
             $t = Time::C->new($year);
         }
@@ -146,7 +146,7 @@ method mktime ($c: :$epoch =, :$second =, :$minute =, :$hour =, :$mday =, :$mont
             if (defined $minute) { $t->minute = $minute; }
             if (defined $second) { $t->second = $second; }
         } elsif (defined $yday) {
-            $t = Time::C->new($year)->day($yday);
+            $t = Time::C->new($year)->day_of_year($yday);
 
             # Now add the time bits on top...
             if (defined $hour) { $t->hour = $hour; }
@@ -157,6 +157,11 @@ method mktime ($c: :$epoch =, :$second =, :$minute =, :$hour =, :$mday =, :$mont
             # So let's just make a time for today's date
             $t = Time::C->now($tz)->second_of_day(0)->tz('UTC', 1);
 
+            # Mark these as being undefined
+            $t->{epoch_d} = $t->{tz_d} = $t->{offset} = $t->{year} =
+              $t->{month} = $t->{mday} = $t->{week} = $t->{wday} = $t->{yday} =
+              $t->{hour} = $t->{minute} = $t->{second} = 0;
+
             croak "Could not mktime: No date specified and no time given."
               if not defined $hour and not defined $minute and not defined $second;
 
@@ -224,7 +229,6 @@ method strptime ($c: $str, $format, :$locale = 'C', :$strict = 1) {
     my %struct;
     if (ref $c) {
         my $t = $c;
-        if ($t->{epoch_d}) { $struct{epoch} = $t->{epoch}; }
         if ($t->{year}) { $struct{year} = $t->year; }
         if ($t->{month}) { $struct{month} = $t->month; }
         if ($t->{mday}) { $struct{mday} = $t->day; }
@@ -745,7 +749,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
